<?php
if (!function_exists('the_blogging_banner_slider_args')) :
    /**
     * Banner Slider Details
     *
     * @since The Blogging 1.0.0
     *
     * @return array $qargs Slider details.
     */
    function the_blogging_banner_slider_args()
    {
        $the_blogging_banner_slider_number = absint(the_blogging_get_option('number_of_home_slider'));
        $the_blogging_banner_slider_from = esc_attr(the_blogging_get_option('select_slider_from'));
        switch ($the_blogging_banner_slider_from) {
            case 'from-page':
                $the_blogging_banner_slider_page_list_array = array();
                for ($i = 1; $i <= $the_blogging_banner_slider_number; $i++) {
                    $the_blogging_banner_slider_page_list = the_blogging_get_option('select_page_for_slider_' . $i);
                    if (!empty($the_blogging_banner_slider_page_list)) {
                        $the_blogging_banner_slider_page_list_array[] = absint($the_blogging_banner_slider_page_list);
                    }
                }
                // Bail if no valid pages are selected.
                if (empty($the_blogging_banner_slider_page_list_array)) {
                    return;
                }
                /*page query*/
                $qargs = array(
                    'posts_per_page' => esc_attr($the_blogging_banner_slider_number),
                    'orderby' => 'post__in',
                    'post_type' => 'page',
                    'post__in' => $the_blogging_banner_slider_page_list_array,
                );
                return $qargs;
                break;

            case 'from-category':
                $the_blogging_banner_slider_category = esc_attr(the_blogging_get_option('select_category_for_slider'));
                $qargs = array(
                    'posts_per_page' => esc_attr($the_blogging_banner_slider_number),
                    'post_type' => 'post',
                    'cat' => $the_blogging_banner_slider_category,
                );
                return $qargs;
                break;

            default:
                break;
        }
        ?>
        <?php
    }
endif;


if (!function_exists('the_blogging_banner_slider')) :
    /**
     * Banner Slider
     *
     * @since The Blogging 1.0.0
     *
     */
    function the_blogging_banner_slider()
    {
        $the_blogging_slider_button_text = esc_html(the_blogging_get_option('button_text_on_slider'));

        $the_blogging_slider_excerpt_number = absint(the_blogging_get_option('number_of_content_home_slider'));
        if (1 != the_blogging_get_option('show_slider_section')) {
            return null;
        }
        $the_blogging_banner_slider_args = the_blogging_banner_slider_args();
        $the_blogging_banner_slider_query = new WP_Query($the_blogging_banner_slider_args); ?>
        <section class="twp-slider-wrapper">
            <?php 
                $the_blogging_banner_background_color = the_blogging_get_option('banner_background_color');
                $the_blogging_banner_text_color = the_blogging_get_option('banner_text_color');
            ?>
            <div class="twp-slider-bgwrapper"  style="background-color:<?php echo esc_attr($the_blogging_banner_background_color) ?>;"></div>
            <div class="container">
                <!-- scrolling banner carousel -->
                <?php do_action('the_blogging_action_banner_carousel'); ?>
                <?php $rtl_class_c = 'false';
                if(is_rtl()){ 
                    $rtl_class_c = 'true';
                }?>
                <div class="twp-slider twp-slider-main" data-slick='{"rtl": <?php echo($rtl_class_c); ?>}'>
                    <?php
                    if ($the_blogging_banner_slider_query->have_posts()) :
                        while ($the_blogging_banner_slider_query->have_posts()) : $the_blogging_banner_slider_query->the_post();
                            if (has_post_thumbnail()) {
                                $thumb = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'the-blogging-main-banner');
                                $url = isset( $thumb[0] ) ? $thumb[0] : '';
                            }
                            if (has_excerpt()) {
                                $the_blogging_slider_content = get_the_excerpt();
                            } else {
                                $the_blogging_slider_content = the_blogging_words_count($the_blogging_slider_excerpt_number, get_the_content());
                            }
                            ?>
                            <div class="single-slide">
                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="slide-bg-wrapper">
                                            <div class="slide-bg bg-image">
                                                <?php if (has_post_thumbnail()) { ?> 
                                                    <img src="<?php echo esc_url($url); ?>">
                                                <?php  } ?>
                                            </div>
                                            <a href="<?php the_permalink(); ?>" class="article-item-link"></a>
                                            <?php if (1 == the_blogging_get_option('enable_slider_overlay')) { ?>
                                                <div class="slider-overlay"></div>
                                            <?php } ?>
                                        </div>
                                    </div>
                                    <div class="col-md-8 col-md-offset-2 col-sm-12">
                                        <div class="slide-text">
                                            <div class="slide-text-wrapper">
                                                <div class="post-category post-category-1">
                                                    <?php the_blogging_entry_category_no_seperator(); ?>
                                                </div>
                                                <h2>
                                                    <a href="<?php the_permalink(); ?>">
                                                        <?php the_title(); ?>
                                                    </a>
                                                </h2>
                                                <?php if ($the_blogging_slider_excerpt_number > 1) { ?>
                                                    <p class="visible hidden-xs"><?php echo wp_kses_post($the_blogging_slider_content); ?></p>
                                                <?php } ?>

                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php
                        endwhile;
                        wp_reset_postdata();
                    endif; ?>
                </div>
                <div class="below-banner">
                    <div class="row">
                        <?php
                            $the_blogging_featured_slider_category = esc_attr(the_blogging_get_option('select_category_for_post_below_slider'));
                                $qarg = array(
                                    'posts_per_page' => 4,
                                    'post_type' => 'post',
                                    'cat' => $the_blogging_featured_slider_category,
                                );
                            $the_blogging_featured_slider_querys = new WP_Query($qarg);
                            ?>
                            <?php
                            if ($the_blogging_featured_slider_querys->have_posts()) :
                                while ($the_blogging_featured_slider_querys->have_posts()) : $the_blogging_featured_slider_querys->the_post();
                                    if (has_post_thumbnail()) {
                                        $thumb = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'the-blogging-main-banner');
                                        $urls = $thumb['0'];
                                    }
                                    ?>
                                    <div class="col-sm-3">
                                        <?php if (has_post_thumbnail()) { ?>
                                            <div class="article-image">
                                                <a href="<?php the_permalink(); ?>" class="bg-image bg-image-light bg-image-2">
                                                    <img src="<?php echo esc_url($urls); ?>">
                                                </a>
                                                <div class="post-category post-category-1">
                                                    <?php the_blogging_entry_category(); ?>
                                                </div>
                                            </div>
                                        <?php } ?>
                                        <div class="content">
                                            <div class="entry-meta">
                                                <?php the_blogging_posted_details_date_name(); ?>
                                            </div>
                                            <h3 class="entry-title entry-title-medium">
                                                <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                            </h3>
                                        </div>
                                    </div>
                                    <?php
                                endwhile;
                                wp_reset_postdata();
                            endif; ?>
                    </div>
                </div>
            </div>
        </section>
        <?php
    }
endif;
add_action('the_blogging_action_slider_post_1', 'the_blogging_banner_slider', 10);